@@ -29,7 +29,7 @@ def export_data():
     default_file_loc = xw.apps.active.books.active.fullname
     layout = [[sg.Text('Select the file location of the master sheet'), sg.Input(default_file_loc),sg.FileBrowse(key="--input_file--")],
                 [sg.OK(), sg.Cancel()]]
-    event, values = sg.Window("",layout, no_titlebar=True, keep_on_top=True, grab_anywhere=True).read(close=True)
+    event, values = sg.Window("",layout, no_titlebar=False, keep_on_top=True, grab_anywhere=True).read(close=True)
 
     xlsx_filename=values[0]
     
@@ -128,7 +128,7 @@ def export_data():
     src_path = AMAZON_MASTER_FILE
     layout = [[sg.Text('Select the output location of your master sheet'), sg.Input(),sg.FolderBrowse(key="--input_file--")],
                 [sg.OK(), sg.Cancel()]]
-    event, values = sg.Window("",layout, no_titlebar=True, keep_on_top=True, grab_anywhere=True).read(close=True)
+    event, values = sg.Window("",layout, no_titlebar=False, keep_on_top=True, grab_anywhere=True).read(close=True)
 
     dest_path=os.path.join(values[0], "amazon_master_output.xlsm")
 
@@ -200,6 +200,8 @@ def generate_sku(allowed_data_types = [str]):
     active_cells.value = [[sku_helper(product_name)] for product_name in input_col_name_1]
 
 
-# if __name__=="__main__":
-#     export_data()
+if __name__ == "__main__":
+    import PySimpleGUI as sg
+    sg.popup("hiiii")
+    export_data()
 
